OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "S'ha produït un error mentre s'analitzava el registre",
    "Copy" : "Copia",
    "Copy raw" : "Copia en brut",
    "Copy formatted" : "Copia formatat",
    "No server logs" : "No hi ha registres del servidor",
    "One or more entries are hidden by the log level filter" : "Una o més entrades estan amagades pel filtre de nivell de registre",
    "Everything is working fine" : "Tot funciona bé",
    "Level" : "Nivell",
    "App" : "Aplicació",
    "Message" : "Missatge",
    "Time" : "Hora",
    "Log levels" : "Nivells de registre",
    "Log content" : "Contingut del registre",
    "Live update" : "Actualització en directe",
    "Download logs" : "Descarrega els registres",
    "Logging" : "Registre",
    "Log Reader" : "Lector de registre",
    "A log reader for Nextcloud" : "Un lector de registre per Nextcloud",
    "Log reader for Nextcloud" : "Lector de registre per Nextcloud",
    "Cased by " : "Emmarcat per"
},
"nplurals=2; plural=(n != 1);");
